mix popcorn.cook (Popcorn v0.2.2)

Generates static artifacts to run the project in the browser.

Accepts the following options:

  • out_dir - the directory to write artifacts to
  • target - wasm (default) or unix. If unix is chosed, you need to build the runtime first with mix popcorn.build_runtime --target unix
  • --include-vm - include the VM and supporting files in the output directory. Without this flag, only the .avm bundle is generated.

out_dir is mandatory, unless provided via config.exs, for example config :popcorn, out_dir: "dist/wasm"